# automate-django
A python script to automate your django production,
It creates a boilerplate,
connects to urls.py, views.py, template files, css and runs the django server and opens the content in browser automatically and output the boilerplate project directly.


## steps for installing on mac, linux and windows:
### note: needs django=1.10 for running this script and python version 3 up

install neccessary setup files

python 3+: 

install from https://python.org

just run automate_django.py on your terminal

run automate-django.py from project folder you want to create with

enter project name and application name and sit back:

your project will be running in your default browser

you can edit reuse code 

enjoy!!!
